cheesecake.codeparser

Package cheesecake :: Module codeparser |
[hide private]
[frames] | no frames]

## Module codeparser
source code

Classes | [hide private]
CodeParser | Information about the structure of a Python module.

Functions | [hide private]
| compile_regex(pattern, user_map=None) Compile a regex pattern using default or user mapping.
| inline_markup(start, end=None, mapping=None)
| line_markup(start, end=None)
| use_format(text, format) Return True if text includes given documentation format and False otherwise.

Variables | [hide private]
get_doctests |
supported_formats |

Function Details | [hide private]

### compile_regex(pattern, user_map=None) | source code
Compile a regex pattern using default or user mapping.

### inline_markup(start, end=None, mapping=None) | source code

### line_markup(start, end=None) | source code

### use_format(text, format) | source code
Return True if text includes given documentation format and False otherwise. See supported_formats for list of known formats.

Variables Details | [hide private]

    ### get_doctests Value:
        <function _extract_examples at 0xb7ad3c34>

    ### supported_formats Value:
        {'epytext': [<_sre.SRE_Pattern object at 0xb79c1860>,
                     <_sre.SRE_Pattern object at 0x82d66b8>,
                     <_sre.SRE_Pattern object at 0x82d6aa8>,
                     <_sre.SRE_Pattern object at 0x82d6d40>],
         'javadoc': [<_sre.SRE_Pattern object at 0xb7aafc98>,
                     <_sre.SRE_Pattern object at 0x82d70c0>,
                     <_sre.SRE_Pattern object at 0x82d7420>],
         'reST': [<_sre.SRE_Pattern object at 0x82ca0d0>,
        ...